.. _about:

About scippneutron
==================

``scippneutron`` builds on top of ``scipp`` and provides features specific to handling and reducing data generated in neutron scattering facilities.
A key example is "unit conversion", e.g., from time-of-flight to energy transfer in an inelastic neutron scattering experiment at a spallation-based neutron source.

Development
-----------

Scippneutron is a open source project by the `European Spallation Source ERIC <https://europeanspallationsource.se/>`_ (ESS).
Other major contributions were provided by the `Science and Technology Facilities Council <https://www.ukri.org/councils/stfc/>`_ (STFC).

References and citations
------------------------

An article about scipp has been published in the conference proceedings of ICANS, see `Scipp: Scientific data handling with labeled multi-dimensional arrays for C++ and Python <https://content.iospress.com/articles/journal-of-neutron-research/jnr190131>`_ or `the paywall-free copy on the Arxiv <https://arxiv.org/abs/2010.00257>`_.

A significant amount of changes such as multi-threading and support for realigned (event) data has gone into scipp since the publication so we recommend to also cite the scipp documentation pages.

License
-------

Scippneutron is available as open source under the `BSD-3 license <https://opensource.org/licenses/BSD-3-Clause>`_.

Source code and development
---------------------------

Scippneutron is hosted and developed `on GitHub <https://github.com/scipp/scippneutron/projects>`_.
